@@ -18,7 +18,7 @@ Version 0.09
 
 =cut
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 =head1 SYNOPSIS
 
@@ -147,7 +147,8 @@ sub default_options {
         cache_file => 0, # Default set by field method below
         auto_login => 0, # Default set by field method below
         human => 0,      # Default set by field method below
-        config_file => 0
+        config_file => 0,
+        use_defaults => 0
     };
     
     return $self->{default_options};
@@ -181,6 +182,7 @@ field 'password';
 field cache_file => 'login_cache';
 field auto_login => 0;
 field human => 1;
+field use_defaults => 0;
 
 stub 'site_info';
 
@@ -278,6 +280,12 @@ trying to use multiple accounts to spam users who don't
 want to hear what you have to say, you should turn this off
 because it'll make your spamming go faster.
 
+=head2 use_defaults
+
+When set to a true value, cached username and password will be used, and
+the user will only be prompted for a username and password if one or both
+aren't already stored.
+
 =cut
 
 
@@ -601,7 +609,7 @@ sub _new_mech {
 sub _get_acct {
 
     # Initialize
-    my %prefs = ();
+    my $prefs = {};
     my $ref = "";
     my ( $pref, $value, $res );
     my $cache_filepath = catfile( $self->cache_dir, $self->cache_file);
@@ -611,22 +619,44 @@ sub _get_acct {
         while (<PREFS>) {
             chomp;
             ( $pref, $value ) = split( ":" );
-            $prefs{"$pref"} = $value;
+            $prefs->{"$pref"} = $value;
         }
         
         close PREFS;
     }
 
+    # If we have a username and password, and they asked us to use the
+    # cached defaults, then skip the login prompts.  Otherwise, prompt
+    # the user for login info.
+    unless ( $self->use_defaults && $prefs->{'email'} && $prefs->{'password'} ) {
+        $prefs = $self->_prompt_for_login( $prefs );
+    }
+    
+    # Store the account info.
+    $self->{account_name}=$prefs->{"email"};
+    $self->{password}=$prefs->{"password"};
+}
+
+# _prompt_for_login( { email => $email, password => $password } )
+#
+# Given an optional email and password, prompt the user, displaying the
+# existing email and password as defaults (well, passwords are displayed as
+# "*****").  Returns the email and password entered, or defaulted to,
+# by the user.
+#
+sub _prompt_for_login {
+    my ( $prefs ) = @_;
+
     # Prompt them for current values
-    unless ( defined $prefs{"email"} ) { $prefs{"email"} = "" }
-    print "Email [" . $prefs{"email"} . "]: ";
-    $res = <STDIN>; chomp $res;
+    unless ( defined $prefs->{"email"} ) { $prefs->{"email"} = "" }
+    print "Email [" . $prefs->{"email"} . "]: ";
+    my $res = ReadLine 0; chomp $res;
     if ( $res ) {
-        $prefs{"email"} = $res;
+        $prefs->{"email"} = $res;
     }
 
-    unless ( defined $prefs{"password"} ) { $prefs{"password"} = "" }
-    my $password_indicator = $prefs{'password'} ? '*****' : '';
+    unless ( defined $prefs->{"password"} ) { $prefs->{"password"} = "" }
+    my $password_indicator = $prefs->{'password'} ? '*****' : '';
     print "Password [". $password_indicator . "]: ";
     ReadMode 'noecho'; # From Term::ReadKey.  Make password not echo.
     $res = ReadLine 0;
@@ -634,7 +664,7 @@ sub _get_acct {
     ReadMode 'normal';
     print "\n"; # Because ReadLine won't output a new line when they hit return
     if ( $res ) {
-        $prefs{"password"} = $res;
+        $prefs->{"password"} = $res;
     }
 
     # Make the cache directory if it doesn't exist.
@@ -642,15 +672,14 @@ sub _get_acct {
 
     # Store the new values.  We clobber the file, set it r/w by the user,
     # *then* write.
+    my $cache_filepath = catfile( $self->cache_dir, $self->cache_file);
     open ( PREFS, ">", $cache_filepath ) or croak $!;
     chmod 0600, $cache_filepath;
-    print PREFS "email:" . $prefs{"email"} . "\n" .
-        "password:" . $prefs{"password"} . "\n";
+    print PREFS "email:" . $prefs->{"email"} . "\n" .
+        "password:" . $prefs->{"password"} . "\n";
     close PREFS || croak "Error closing file when writing username/password: $!";
-    
-    # Store the account info.
-    $self->{account_name}=$prefs{"email"};
-    $self->{password}=$prefs{"password"};
+
+    return $prefs;
 }
 
 =head2 logout
